@@ -91,6 +91,7 @@ using namespace DOM;
         {
             noBorder = false;
             left = right = top = bottom = 0;
+            clearButtonOverlay = 0;
             setParent(parent);
         }
 
@@ -101,7 +102,7 @@ using namespace DOM;
               case QStyle::SE_PushButtonContents:
               case QStyle::SE_LineEditContents:
               case QStyle::SE_ShapedFrameContents:
-                r.adjust(left, top, -right, -bottom);
+                r.adjust(left, top, -qMax(0, right - clearButtonOverlay), -bottom);
               default:
                 break;
             }
@@ -131,7 +132,6 @@ using namespace DOM;
                     if (noBorder) {
                         // Need to expand a bit for some styles
                         comboOpt.rect.adjust(-1, -2, 1, 2);
-                        comboOpt.rect.translate(-1, 0);
                         comboOpt.state &= ~State_On;
                     }
                     return style()->drawControl(element, &comboOpt, painter, widget);
@@ -147,26 +147,27 @@ using namespace DOM;
                 if (const QStyleOptionComboBox *cbOpt = qstyleoption_cast<const QStyleOptionComboBox*>(opt)) {
                     bool enabled = (cbOpt->state & State_Enabled);
                     QColor color = cbOpt->palette.color(QPalette::ButtonText);
-                    if (color.value() < 128)
-                        color = color.lighter();
                     painter->save();
                     painter->setBackgroundMode(Qt::TransparentMode);
                     painter->setPen(color);
+                    painter->setRenderHint(QPainter::Antialiasing);
                     // Drop down indicator
-                    painter->setBrush(enabled ? QBrush(color, Qt::SolidPattern) : Qt::NoBrush);
                     QRect arrowRect = style()->subControlRect(cc, opt, SC_ComboBoxArrow, widget);
+                    arrowRect.setTop(cbOpt->rect.top());
+                    arrowRect.setBottom(cbOpt->rect.bottom());
+                    arrowRect.setRight(cbOpt->rect.right() - 1);
                     if (enabled && (cbOpt->state & State_On))
                         arrowRect.translate(1, 1); // push effect
-                    const int arrowDown[] = { 5,-2, 0,3, -5,-2, -4,-3, -3,-3, 0,0, 3,-3, 4,-3 };
-                    QPolygon a(8);
-                    a.setPoints(8, arrowDown);
-                    a.translate((arrowRect.x() + (arrowRect.width() >> 1)), (arrowRect.y() + (arrowRect.height() >> 1)));
-                    painter->drawPolygon(a);
-                    // Focus rect
+                    //if (!enabled) color = color.lighter();
+                    painter->setBrush(enabled ? QBrush(color, Qt::SolidPattern) : Qt::NoBrush);
+                    QPolygon cbArrowDown;
+                    cbArrowDown.setPoints(6,  3,-2, 4,-2, 0,2, -4,-2, -3,-2, 0,1);
+                    cbArrowDown.translate((arrowRect.x() + (arrowRect.width() >> 1)), (arrowRect.y() + (arrowRect.height() >> 1)));
+                    painter->drawPolygon(cbArrowDown);
+                    // Focus rect (from qcleanlooksstyle)
                     if (enabled && (cbOpt->state & State_HasFocus)) {
                         QRect focusRect = style()->subElementRect(SE_ComboBoxFocusRect, cbOpt, widget);
                         focusRect.adjust(0, -2, 0, 2);
-                        // Begin drawing focus rect (from qcleanlooksstyle)
                         painter->setBrush(QBrush(color, Qt::Dense4Pattern));
                         painter->setBrushOrigin(focusRect.topLeft());
                         painter->setPen(Qt::NoPen);
@@ -177,7 +178,6 @@ using namespace DOM;
                             QRect(focusRect.right(), focusRect.top(), 1, focusRect.height())   // Right
                         };
                         painter->drawRects(rects, 4);
-                        // End drawing focus rect
                     }
                     painter->restore();
 
@@ -224,6 +224,7 @@ using namespace DOM;
         }
 
         int left, right, top, bottom;
+        int clearButtonOverlay;
         bool noBorder;
     };
 
@@ -558,6 +559,8 @@ RenderSubmitButton::RenderSubmitButton(HTMLInputElementImpl *element)
     setQWidget(p);
     //p->setAutoMask(true);
     p->setMouseTracking(true);
+    p->setDefault(false);
+    p->setAutoDefault(false);
 }
 
 static inline void setStyleSheet_helper(const QString& s, QWidget* w)
@@ -663,13 +666,9 @@ void RenderSubmitButton::calcMinMaxWidth()
     s = s.expandedTo(QApplication::globalStrut());
     int margin = pb->style()->pixelMetric( QStyle::PM_ButtonMargin) +
               pb->style()->pixelMetric( QStyle::PM_DefaultFrameWidth ) * 2;
-    int w = ts.width() + margin;
 
+    int w = ts.width() + margin;
     int h = s.height();
-    if (pb->isDefault() || pb->autoDefault()) {
-        int dbw = pb->style()->pixelMetric( QStyle::PM_ButtonDefaultIndicator ) * 2;
-        w += dbw;
-    }
 
     assert(includesPadding());
     int hpadding = RenderWidget::paddingLeft() + RenderWidget::paddingRight();
@@ -1122,6 +1121,10 @@ void RenderLineEdit::setStyle(RenderStyle* _style)
             }
         }
     }
+
+    if (m_proxyStyle) {
+        static_cast<KHTMLProxyStyle*>(m_proxyStyle)->clearButtonOverlay = qMax(0, widget()->clearButtonUsedSize().width());
+    }
 }
 
 void RenderLineEdit::highLightWord( unsigned int length, unsigned int pos )
@@ -2213,8 +2216,6 @@ void TextAreaWidget::keyPressEvent(QKeyEvent *e)
 RenderTextArea::RenderTextArea(HTMLTextAreaElementImpl *element)
     : RenderFormElement(element)
 {
-    scrollbarsStyled = false;
-
     TextAreaWidget *edit = new TextAreaWidget(element->wrap(), view());
     setQWidget(edit);
     const KHTMLSettings *settings = view()->part()->settings();
@@ -2306,8 +2307,6 @@ void RenderTextArea::setStyle(RenderStyle* _style)
         element()->m_unsubmittedFormChange = unsubmittedFormChange;
     }
 
-    scrollbarsStyled = false;
-
     if (style()->overflowX() == OSCROLL)
         w->setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOn );
     else if (style()->overflowX() == OHIDDEN)
@@ -2322,21 +2321,6 @@ void RenderTextArea::setStyle(RenderStyle* _style)
         w->setVerticalScrollBarPolicy( Qt::ScrollBarAsNeeded );
 }
 
-void RenderTextArea::layout()
-{
-    KHTMLAssert( needsLayout() );
-
-    RenderFormElement::layout();
-
-    TextAreaWidget* w = static_cast<TextAreaWidget*>(m_widget);
-
-    if (!scrollbarsStyled) {
-        w->horizontalScrollBar()->setPalette(style()->palette());
-        w->verticalScrollBar()->setPalette(style()->palette());
-        scrollbarsStyled=true;
-    }
-}
-
 short RenderTextArea::scrollWidth() const
 {
     return RenderObject::scrollWidth();
