@@ -31,6 +31,7 @@
 #include "function.h"
 #include "interpreter.h"
 #include "nodes.h"
+#include "commonunicode.h"
 #include "wtf/ASCIICType.h"
 #include "wtf/DisallowCType.h"
 #include <wtf/unicode/libc/UnicodeLibC.h>
@@ -617,33 +618,7 @@ int Lexer::lex()
 
 bool Lexer::isWhiteSpace() const
 {
-    switch (current) {
-    case 0x0009:  // TAB
-    case 0x000B:  // VERTICAL TAB
-    case 0x000C:  // FORM FEED
-    case 0x0020:  // SPACE
-    case 0x00A0:  // NO-BREAK SPACE
-    case 0x1680:  // OGHAM SPACE MARK
-    case 0x180E:  // MONGOLIAN VOWEL SEPARATOR
-    case 0x2000:  // EN QUAD
-    case 0x2001:  // EM QUAD
-    case 0x2002:  // EN SPACE
-    case 0x2003:  // EM SPACE
-    case 0x2004:  // THREE-PER-EM SPACE
-    case 0x2005:  // FOUR-PER-EM SPACE
-    case 0x2006:  // SIX-PER-EM SPACE
-    case 0x2007:  // FIGURE SPACE
-    case 0x2008:  // PUNCTUATION SPACE
-    case 0x2009:  // THIN SPACE
-    case 0x200A:  // HAIR SPACE
-    case 0x202F:  // NARROW NO-BREAK SPACE
-    case 0x205F:  // MEDIUM MATHEMATICAL SPACE
-    case 0x3000:  // IDEOGRAPHIC SPACE
-    case 0xFEFF:  // BOM/ZWNBS
-        return true;
-    default:
-        return false;
-    }
+    return CommonUnicode::isWhiteSpace(current);
 }
 
 bool Lexer::isLineTerminator()
